Ext2BlockGroupDescriptor

Struct Ext2BlockGroupDescriptor 

#[repr(C, packed(1))]
pub struct Ext2BlockGroupDescriptor { pub block_bitmap: u32, pub inode_bitmap: u32, pub inode_table: u32, pub free_blocks_count: u16, pub free_inodes_count: u16, pub used_dirs_count: u16, pub pad: u16, pub reserved: [u32; 3], }
ext2 Block Group Descriptor

Each block group has a descriptor that contains information about the location of important data structures within that group.

Fields

block_bitmap: u32

Block address of block bitmap

inode_bitmap: u32

Block address of inode bitmap

inode_table: u32

Block address of inode table

free_blocks_count: u16

Number of free blocks in group

free_inodes_count: u16

Number of free inodes in group

used_dirs_count: u16

Number of directories in group

pad: u16

Padding to 32 bytes

reserved: [u32; 3]

Reserved for future use

Implementations

Source

impl Ext2BlockGroupDescriptor

pub fn from_bytes(data: &[u8]) -> Result<Self, FileSystemError>

Parse block group descriptor from raw bytes using unsafe type conversion

pub fn get_block_bitmap(&self) -> u32

Get block bitmap address

pub fn get_inode_bitmap(&self) -> u32

Get inode bitmap address

pub fn get_inode_table(&self) -> u32

Get inode table address

pub fn get_free_blocks_count(&self) -> u16

Get free blocks count

pub fn set_free_blocks_count(&mut self, count: u16)

Set free blocks count

pub fn get_free_inodes_count(&self) -> u16

Get free inodes count

pub fn set_free_inodes_count(&mut self, count: u16)

Set free inodes count

pub fn get_used_dirs_count(&self) -> u16

Get used directories count

pub fn set_used_dirs_count(&mut self, count: u16)

Set used directories count

pub fn write_to_bytes(&self, data: &mut [u8])

Write the descriptor back to bytes